@@ -94,13 +94,16 @@ from .usecases.child_monitoring import ChildMonitoringConfig
 from .usecases.gender_detection import GenderDetectionConfig
 from .usecases.concrete_crack_detection import ConcreteCrackConfig
 from .usecases.fashion_detection import FashionDetectionConfig, FashionDetectionUseCase
+from .usecases.shelf_inventory_detection import ShelfInventoryConfig
 
 from .usecases.warehouse_object_segmentation import WarehouseObjectConfig
 from .usecases.shopping_cart_analysis import ShoppingCartConfig
+from .usecases.anti_spoofing_detection import AntiSpoofingDetectionConfig
 
 from .usecases.shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
 from .usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
 from .usecases.assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
+from .usecases.car_part_segmentation import CarPartSegmentationUseCase, CarPartSegmentationConfig
 
 # Use case implementations
 from .usecases import (
@@ -140,7 +143,11 @@ from .usecases import (
     WarehouseObjectUseCase,
     ShoppingCartUseCase,
     BottleDefectUseCase,
-    AssemblyLineUseCase
+    AssemblyLineUseCase,
+    AntiSpoofingDetectionUseCase,
+    ShelfInventoryUseCase,
+
+    CarPartSegmentationUseCase
 )
 
 # Register use cases automatically
@@ -165,6 +172,7 @@ _banana_defect_detection = BananaMonitoringUseCase()
 _chicken_pose_detection = ChickenPoseDetectionUseCase()
 _theft_detection = TheftDetectionUseCase()
 _traffic_sign_monitoring = TrafficSignMonitoringUseCase()
+_shelf_inventory = ShelfInventoryUseCase()
 
 _weld_defect_detection = WeldDefectUseCase()
 _pricetag_detection = PriceTagUseCase()
@@ -181,11 +189,13 @@ _fashion_detection = FashionDetectionUseCase()
 
 _warehouse_object_segmentation = WarehouseObjectUseCase()
 _shopping_cart_analysis = ShoppingCartUseCase()
+_anti_spoofing_detection = AntiSpoofingDetectionUseCase()
 
 
 _shoplifting_detection = ShopliftingDetectionUseCase()
 _defect_detection_products = BottleDefectUseCase()
 _assembly_line_detection = AssemblyLineUseCase()
+_car_part_segmentation = CarPartSegmentationUseCase()
 
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
@@ -211,6 +221,8 @@ registry.register_use_case(_chicken_pose_detection.category, _chicken_pose_detec
 registry.register_use_case(_theft_detection.category, _theft_detection.name, TheftDetectionUseCase)
 registry.register_use_case(_traffic_sign_monitoring.category, _traffic_sign_monitoring.name, TrafficSignMonitoringUseCase)
 registry.register_use_case(_gender_detection.category, _gender_detection.name, GenderDetectionUseCase)
+registry.register_use_case(_anti_spoofing_detection.category, _anti_spoofing_detection.name, AntiSpoofingDetectionUseCase)
+registry.register_use_case(_shelf_inventory.category, _shelf_inventory.name, ShelfInventoryUseCase)
 
 registry.register_use_case(_car_damage.category, _car_damage.name, CarDamageDetectionUseCase)
 registry.register_use_case(_distracted_driver.category, _distracted_driver.name, DistractedDriverUseCase)
@@ -230,6 +242,7 @@ registry.register_use_case(_shopping_cart_analysis.category, _shopping_cart_anal
 registry.register_use_case(_shoplifting_detection.category, _shoplifting_detection.name, ShopliftingDetectionUseCase)
 registry.register_use_case(_defect_detection_products.category, _defect_detection_products.name, BottleDefectUseCase)
 registry.register_use_case(_assembly_line_detection.category, _assembly_line_detection.name, AssemblyLineUseCase)
+registry.register_use_case(_car_part_segmentation.category, _car_part_segmentation.name, CarPartSegmentationUseCase)
 
 # Utility functions - organized by category
 from .utils import (  # noqa: E402
@@ -400,6 +413,9 @@ __all__ = [
     'ShoppingCartConfig',
     'BottleDefectConfig',
     'AssemblyLineConfig',
+    'AntiSpoofingDetectionConfig',
+    'ShelfInventoryConfig',
+    'CarPartSegmentationConfig',
 
     # Use case classes
     'PeopleCountingUseCase',
@@ -431,6 +447,7 @@ __all__ = [
     'TheftDetectionUseCase',
     'TrafficSignMonitoringUseCase',
     'WeaponDetectionUseCase',
+    'ShelfInventoryUseCase',
 
     'CropWeedDetectionUseCase',
     'ChildMonitoringUseCase',
@@ -441,6 +458,8 @@ __all__ = [
     'ShoppingCartUseCase',
     'BottleDefectUseCase',
     'AssemblyLineUseCase',
+    'AntiSpoofingDetectionUseCase',
+    'CarPartSegmentationUseCase',
     
     # Base classes for extension
     'BaseProcessor',
