@@ -38,6 +38,7 @@ from ..usecases.gender_detection import GenderDetectionConfig, GenderDetectionUs
 from ..usecases.weapon_detection import WeaponDetectionUseCase,WeaponDetectionConfig
 from ..usecases.concrete_crack_detection import ConcreteCrackUseCase, ConcreteCrackConfig
 from ..usecases.fashion_detection import FashionDetectionUseCase, FashionDetectionConfig
+from ..usecases.anti_spoofing_detection import AntiSpoofingDetectionUseCase, AntiSpoofingDetectionConfig
 
 from ..usecases.warehouse_object_segmentation import WarehouseObjectUseCase, WarehouseObjectConfig
 from ..usecases.shopping_cart_analysis import ShoppingCartUseCase, ShoppingCartConfig
@@ -45,6 +46,8 @@ from ..usecases.assembly_line_detection import AssemblyLineUseCase, AssemblyLine
 
 from ..usecases.shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
 from ..usecases.defect_detection_products import BottleDefectUseCase, BottleDefectConfig
+from ..usecases.shelf_inventory_detection import ShelfInventoryConfig,ShelfInventoryUseCase
+from ..usecases.car_part_segmentation import CarPartSegmentationUseCase, CarPartSegmentationConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -58,6 +61,8 @@ __all__ = [
     'VehicleMonitoringUseCase',
     'FireSmokeUseCase',
     'PotholeSegmentationUseCase',
+    'AntiSpoofingDetectionUseCase',
+    'ShelfInventoryUseCase',
 
     'ShopliftingDetectionUseCase',
     'ParkingSpaceUseCase',
@@ -86,6 +91,7 @@ __all__ = [
     'ShoppingCartUseCase',
     'BottleDefectUseCase',
     'AssemblyLineUseCase',
+    'CarPartSegmentationUseCase',
 
 
 
@@ -126,5 +132,8 @@ __all__ = [
     'WarehouseObjectConfig',
     'ShoppingCartConfig',
     'BottleDefectConfig',
-    'AssemblyLineConfig'
+    'AssemblyLineConfig',
+    'AntiSpoofingDetectionConfig',
+    'ShelfInventoryConfig',
+    'CarPartSegmentationConfig',
 ]
