@@ -422,7 +422,9 @@ class ConfigManager:
             "shopping_cart_analysis": None,
             "defect_detection_products": None,
             'assembly_line_detection': None,
-
+            'anti_spoofing_detection' : None,
+            'shelf_inventory' : None,
+            'car_part_segmentation': None,
         }
 
     def register_config_class(self, usecase: str, config_class: type) -> None:
@@ -453,6 +455,22 @@ class ConfigManager:
         except ImportError:
             return None
         
+    def shelf_inventory_config_class(self):
+        """Get Banana monitoring class to avoid circular imports."""
+        try:
+            from ..usecases.shelf_inventory_detection import ShelfInventoryUseCase
+            return ShelfInventoryUseCase
+        except ImportError:
+            return None
+        
+    def anti_spoofing_detection_config_class(self):
+        """Get Anti-Spoofing class to avoid circular imports."""
+        try:
+            from ..usecases.anti_spoofing_detection import AntiSpoofingDetectionConfig
+            return AntiSpoofingDetectionConfig
+        except ImportError:
+            return None
+        
     def theft_detection_config_class(self):
         """Get  theft detection class to avoid circular imports."""
         try:
@@ -685,6 +703,14 @@ class ConfigManager:
             return AssemblyLineConfig
         except ImportError:
             return None
+    
+    def car_part_segmentation_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.car_part_segmentation import CarPartSegmentationConfig
+            return CarPartSegmentationConfig
+        except ImportError:
+            return None
 
     def create_config(self, usecase: str, category: Optional[str] = None, **kwargs) -> BaseConfig:
         """
@@ -948,6 +974,38 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "shelf_inventory":
+            # Import here to avoid circular import
+            from ..usecases.shelf_inventory_detection import ShelfInventoryConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = ShelfInventoryConfig(
+                category=category or "retail",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
+        elif usecase == "anti_spoofing_detection":
+            # Import here to avoid circular import
+            from ..usecases.anti_spoofing_detection import AntiSpoofingDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = AntiSpoofingDetectionConfig(
+                category=category or "security",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+
         elif usecase == "theft_detection":
             # Import here to avoid circular import
             from ..usecases.theft_detection import TheftDetectionConfig
@@ -1331,6 +1389,22 @@ class ConfigManager:
                 alert_config=alert_config,
                 **kwargs
             )
+        
+        elif usecase == "car_part_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.car_part_segmentation import CarPartSegmentationConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = CarPartSegmentationConfig(
+                category=category or "automobile",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
             
         else:
             raise ConfigValidationError(f"Unknown use case: {usecase}")
@@ -1491,6 +1565,18 @@ class ConfigManager:
             default_config = BananaMonitoringConfig()
             return default_config.to_dict()
         
+        elif usecase == "shelf_inventory":
+            # Import here to avoid circular import
+            from ..usecases.shelf_inventory_detection import ShelfInventoryConfig
+            default_config = ShelfInventoryConfig()
+            return default_config.to_dict()
+
+        elif usecase == "anti_spoofing_detection":
+            # Import here to avoid circular import
+            from ..usecases.anti_spoofing_detection import AntiSpoofingDetectionConfig
+            default_config = AntiSpoofingDetectionConfig()
+            return default_config.to_dict()
+        
         elif usecase == "traffic_sign_monitoring":
             # Import here to avoid circular import
             from ..usecases.traffic_sign_monitoring import TrafficSignMonitoringConfig
@@ -1612,6 +1698,11 @@ class ConfigManager:
             from ..usecases.assembly_line_detection import AssemblyLineConfig
             default_config = AssemblyLineConfig()
             return default_config.to_dict()
+        elif usecase == "car_part_segmentation":
+            # Import here to avoid circular import
+            from ..usecases.car_part_segmentation import CarPartSegmentationConfig
+            default_config = CarPartSegmentationConfig()
+            return default_config.to_dict()
 
         elif usecase not in self._config_classes:
             raise ConfigValidationError(f"Unsupported use case: {usecase}")
