@@ -50,6 +50,9 @@ from .usecases import (
     ChickenPoseDetectionUseCase,
     TheftDetectionUseCase,
     TrafficSignMonitoringUseCase,
+    AntiSpoofingDetectionUseCase,
+    ShelfInventoryUseCase,
+
 
     AgeDetectionUseCase,
     WeldDefectUseCase,
@@ -68,7 +71,8 @@ from .usecases import (
     WarehouseObjectUseCase,
     ShoppingCartUseCase,
     BottleDefectUseCase,
-    AssemblyLineUseCase
+    AssemblyLineUseCase,
+    CarPartSegmentationUseCase,
 
 )
 
@@ -143,6 +147,8 @@ class PostProcessor:
         registry.register_use_case("traffic", "fruit_monitoring", BananaMonitoringUseCase)
         registry.register_use_case("security", "theft_detection", TheftDetectionUseCase)
         registry.register_use_case("traffic", "traffic_sign_monitoring", TrafficSignMonitoringUseCase)
+        registry.register_use_case("security", "anti_spoofing_detection", AntiSpoofingDetectionUseCase)
+        registry.register_use_case("retail", "shelf_inventory", ShelfInventoryUseCase)
         
         registry.register_use_case("hazard", "fire_smoke_detection", FireSmokeUseCase)
         registry.register_use_case("flare_detection", "flare_analysis", FlareAnalysisUseCase)
@@ -171,6 +177,7 @@ class PostProcessor:
         registry.register_use_case("security", "shoplifting_detection", ShopliftingDetectionUseCase)
         registry.register_use_case("retail", "defect_detection_products", BottleDefectUseCase)
         registry.register_use_case("manufacturing", "assembly_line_detection", AssemblyLineUseCase)
+        registry.register_use_case("automobile", "car_part_segmentation", CarPartSegmentationUseCase)
         
         logger.debug("Registered use cases with registry")
     
@@ -289,6 +296,14 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, AssemblyLineUseCase): 
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, AntiSpoofingDetectionUseCase): 
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, ShelfInventoryUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, CarPartSegmentationUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, ConcreteCrackUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
 
             else:
                 result = use_case.process(data, parsed_config, context, stream_info)
