@@ -47,6 +47,9 @@ from .shopping_cart_analysis import ShoppingCartUseCase, ShoppingCartConfig
 from .shoplifting_detection import ShopliftingDetectionConfig, ShopliftingDetectionUseCase
 from .defect_detection_products import BottleDefectUseCase, BottleDefectConfig
 from .assembly_line_detection import AssemblyLineUseCase, AssemblyLineConfig
+from .anti_spoofing_detection import AntiSpoofingDetectionConfig, AntiSpoofingDetectionUseCase
+from .shelf_inventory_detection import ShelfInventoryUseCase,ShelfInventoryConfig
+from .car_part_segmentation import CarPartSegmentationUseCase, CarPartSegmentationConfig
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -87,6 +90,9 @@ __all__ = [
     'ShoppingCartUseCase',
     'BottleDefectUseCase',
     'AssemblyLineUseCase',
+    'AntiSpoofingDetectionUseCase',
+    'ShelfInventoryUseCase',
+    'CarPartSegmentationUseCase',
     'PeopleCountingConfig',
     'ParkingSpaceConfig',
     'CustomerServiceConfig',
@@ -123,5 +129,8 @@ __all__ = [
     'WarehouseObjectConfig',
     'ShoppingCartConfig',
     'BottleDefectConfig',
-    'AssemblyLineConfig'
+    'AssemblyLineConfig',
+    'AntiSpoofingDetectionConfig',
+    'ShelfInventoryConfig',
+    'CarPartSegmentationConfig',
 ]
\ No newline at end of file
