@@ -22,7 +22,7 @@ from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class ConcreteCrackConfig(BaseConfig):
-    """Configuration for Concrete Crack detection use case in Concrete Crack monitoring."""
+    """Configuration for concrete crack detection use case in concrete crack monitoring."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
@@ -31,7 +31,7 @@ class ConcreteCrackConfig(BaseConfig):
     smoothing_confidence_range_factor: float = 0.5
 
     #confidence thresholds
-    confidence_threshold: float = 0.6
+    confidence_threshold: float = 0.2
 
     usecase_categories: List[str] = field(
         default_factory=lambda: ['Cracks']
@@ -267,7 +267,7 @@ class ConcreteCrackUseCase(BaseProcessor):
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,  # Use Concrete Crack threshold as default
+                    confidence_threshold=config.confidence_threshold,  # Use concrete threshold as default
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
@@ -555,7 +555,7 @@ class ConcreteCrackUseCase(BaseProcessor):
 
     # Human-friendly display names for  categories
     CATEGORY_DISPLAY = {
-        "Cracks": "Cracks",
+        "Cracks": "Cracks"
     }
 
     def _generate_insights(self, summary: dict, config: ConcreteCrackConfig) -> List[str]:
