@@ -236,7 +236,7 @@ class PotholeSegmentationUseCase(BaseProcessor):
     def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None,
                 stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
         """
-        Main entry point for  post-processing.
+        Main entry point for post-processing.
         Applies category mapping, smoothing, counting, alerting, and summary generation.
         Returns a ProcessingResult with all relevant outputs.
         """
@@ -253,9 +253,20 @@ class PotholeSegmentationUseCase(BaseProcessor):
         context.input_format = input_format
         context.confidence_threshold = config.confidence_threshold
 
+        # Store original masks to preserve through all steps
+        original_detections = {id(det): det.get("masks", det.get("mask", [])) for det in data}
+        self.logger.debug(f"Input masks: {[det.get('masks', det.get('mask', [])) for det in data]}")
+        
+        # Step 1: Confidence filtering
         if config.confidence_threshold is not None:
             processed_data = filter_by_confidence(data, config.confidence_threshold)
-            self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
+            # Restore masks
+            processed_data = [
+                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
+                for det in processed_data
+            ]
+            self.logger.debug(
+                f"Masks after confidence filtering: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
         else:
             processed_data = data
             self.logger.debug(f"Did not apply confidence filtering with threshold since nothing was provided")
@@ -263,28 +274,49 @@ class PotholeSegmentationUseCase(BaseProcessor):
         # Step 2: Apply category mapping if provided
         if config.index_to_category:
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
-            self.logger.debug("Applied category mapping")
+            # Restore masks
+            processed_data = [
+                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
+                for det in processed_data
+            ]
+            self.logger.debug(
+                f"Masks after category mapping: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
+        # Step 3: Category filtering
         if config.target_categories:
             processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
-            self.logger.debug(f"Applied  category filtering")
+            # Restore masks
+            processed_data = [
+                {**det, "masks": original_detections.get(id(det), det.get("masks", det.get("mask", [])))}
+                for det in processed_data
+            ]
+            self.logger.debug(
+                f"Masks after category filtering: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
-        # Apply bbox smoothing if enabled
+        # Step 4: Apply bbox smoothing if enabled
         if config.enable_smoothing:
             if self.smoothing_tracker is None:
                 smoothing_config = BBoxSmoothingConfig(
                     smoothing_algorithm=config.smoothing_algorithm,
                     window_size=config.smoothing_window_size,
                     cooldown_frames=config.smoothing_cooldown_frames,
-                    confidence_threshold=config.confidence_threshold,  # Use  threshold as default
+                    confidence_threshold=config.confidence_threshold,
                     confidence_range_factor=config.smoothing_confidence_range_factor,
                     enable_smoothing=True
                 )
                 self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
+            # Store masks before smoothing
+            pre_smoothing_detections = {id(det): det.get("masks", det.get("mask", [])) for det in processed_data}
             processed_data = bbox_smoothing(processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
+            # Restore masks after smoothing
+            processed_data = [
+                {**det, "masks": pre_smoothing_detections.get(id(det), det.get("masks", det.get("mask", [])))}
+                for det in processed_data
+            ]
+            self.logger.debug(
+                f"Masks after smoothing: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
-
-        # Advanced tracking (BYTETracker-like)
+        # Step 5: Advanced tracking (BYTETracker-like)
         try:
             from ..advanced_tracker import AdvancedTracker
             from ..advanced_tracker.config import TrackerConfig
@@ -293,20 +325,24 @@ class PotholeSegmentationUseCase(BaseProcessor):
             if self.tracker is None:
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for  Monitoring and tracking")
+                self.logger.info("Initialized AdvancedTracker for Monitoring and tracking")
 
-            # The tracker expects the data in the same format as input
-            # It will add track_id and frame_id to each detection
+            # Store masks before tracking
+            pre_tracking_detections = {id(det): det.get("masks", det.get("mask", [])) for det in processed_data}
             processed_data = self.tracker.update(processed_data)
+            # Restore masks after tracking
+            processed_data = [
+                {**det, "masks": pre_tracking_detections.get(id(det), det.get("masks", det.get("mask", [])))}
+                for det in processed_data
+            ]
+            self.logger.debug(
+                f"Masks after tracking: {[det.get('masks', det.get('mask', [])) for det in processed_data]}")
 
         except Exception as e:
             # If advanced tracker fails, fallback to unsmoothed detections
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
-
-
-
-        # Update  tracking state for total count per label
+        # Update tracking state for total count per label
         self._update_tracking_state(processed_data)
 
         # Update frame counter
@@ -323,18 +359,20 @@ class PotholeSegmentationUseCase(BaseProcessor):
                 frame_number = start_frame
 
         # Compute summaries and alerts
-        general_counting_summary = calculate_counting_summary(data) #done
-        counting_summary = self._count_categories(processed_data, config) #done
-        # Add total unique  counts after tracking using only local state
-        total_counts = self.get_total_counts() #done
-        counting_summary['total_counts'] = total_counts #done
-        insights = self._generate_insights(counting_summary, config)#done
-        alerts = self._check_alerts(counting_summary, config)#done
-        predictions = self._extract_predictions(processed_data)#done
-        summary = self._generate_summary(counting_summary, alerts)#done
+        general_counting_summary = calculate_counting_summary(data)
+        counting_summary = self._count_categories(processed_data, config)
+        # Add total unique counts after tracking using only local state
+        total_counts = self.get_total_counts()
+        counting_summary['total_counts'] = total_counts
+        print("DEBUGGGGGGGGGGGGGGG2")
+        print(processed_data)
+        insights = self._generate_insights(counting_summary, config)
+        alerts = self._check_alerts(counting_summary, config)
+        predictions = self._extract_predictions(processed_data)
+        summary = self._generate_summary(counting_summary, alerts)
 
         # Step: Generate structured events and tracking stats with frame-based keys
-        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)#done
+        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
         tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number,
                                                             stream_info)
 
@@ -365,6 +403,8 @@ class PotholeSegmentationUseCase(BaseProcessor):
 
 
 
+
+
     def _generate_events(self, counting_summary: Dict, alerts: List, config: PotholeConfig,
                          frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[
         Dict]:
