@@ -1,13 +1,21 @@
+"""Module providing deployment functionality."""
+
 import sys
-from matrice.utils import handle_response , get_summary  
+import time
+import json
+from matrice.utils import (
+    handle_response,
+    get_summary,
+)
 from datetime import datetime, timedelta
 
+
 class Deployment:
     """
     Class to manage deployment-related operations within a project.
 
-    The `Deployment` class initializes with a given session and deployment details, 
-    allowing users to access and manage the deployment attributes such as status, 
+    The `Deployment` class initializes with a given session and deployment details,
+    allowing users to access and manage the deployment attributes such as status,
     configuration, and associated project information.
 
     Parameters
@@ -102,18 +110,22 @@ class Deployment:
     >>> deployment = Deployment(session=session, deployment_id="deployment_id", deployment_name="MyDeployment")
     """
 
-
-    def __init__(self, session, deployment_id=None, deployment_name=None):
+    def __init__(
+        self,
+        session,
+        deployment_id=None,
+        deployment_name=None,
+    ):
+        if not (deployment_id or deployment_name):
+            raise ValueError("Either deployment_id or deployment_name must be provided")
+        self.session = session
         self.project_id = session.project_id
         self.last_refresh_time = datetime.now()
-        assert deployment_id or deployment_name, "Either deployment_id or deployment_name must be provided"
-        self.deployment_id = deployment_id #TODO get deployment id with name and check if id maps to the name or not
+        self.deployment_id = deployment_id
         self.deployment_name = deployment_name
-        self.session=session
+        self.session = session
         self.rpc = session.rpc
         self.details, err, message = self._get_details()
-        
-        # Deployment details
         self.deployment_id = self.details.get("_id")
         self.deployment_name = self.details.get("deploymentName")
         self.project_id = self.details.get("_idProject")
@@ -142,12 +154,14 @@ class Deployment:
         self.created_at = self.details.get("createdAt")
         self.updated_at = self.details.get("updatedAt")
         self.compute_alias = self.details.get("computeAlias")
-        self.is_optimized=self.details.get("isOptimized")
-        # Get and store deployment status cards
+        self.is_optimized = self.details.get("isOptimized")
+        self.auth_key = ""
         self.status_cards = self._get_deployment_status_cards()
-        
-        # Get and store summary information
-        summary_response, err, message = get_summary(self.session, self.project_id, "deployments")
+        summary_response, err, message = get_summary(
+            self.session,
+            self.project_id,
+            "deployments",
+        )
         if summary_response:
             summary_data = summary_response
             self.total_deployments = summary_data.get("TotalDeployments")
@@ -161,30 +175,21 @@ class Deployment:
             self.total_running_instances_count = None
             self.hibernated_deployments = None
             self.error_deployments = None
-        
-    
+
     def refresh(self):
         """
         Refresh the instance by reinstantiating it with the previous values.
         """
-        # Check if two minutes have passed since the last refresh
         if datetime.now() - self.last_refresh_time < timedelta(minutes=2):
             raise Exception("Refresh can only be called after two minutes since the last refresh.")
-
-        # Prepare initialization parameters
         init_params = {
-            'session': self.session,
-            'deployment_id': self.deployment_id,
-            'deployment_name': self.deployment_name
+            "session": self.session,
+            "deployment_id": self.deployment_id,
+            "deployment_name": self.deployment_name,
         }
-
-        # Reinitialize the instance
         self.__init__(**init_params)
-
-        # Update the last refresh time
         self.last_refresh_time = datetime.now()
 
-
     def _get_details(self):
         """
         Fetch deployment details using either the deployment ID or deployment name.
@@ -219,8 +224,6 @@ class Deployment:
         """
         id = self.deployment_id
         name = self.deployment_name
-        
-
         if id:
             try:
                 return self._get_deployment_by_id()
@@ -263,7 +266,6 @@ class Deployment:
         """
         path = f"/v1/deployment/{self.deployment_id}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Deployment fetched successfully",
@@ -305,7 +307,6 @@ class Deployment:
             sys.exit(0)
         path = f"/v1/deployment/get_deployment_by_name?deploymentName={self.deployment_name}"
         resp = self.rpc.get(path=path)
-
         return handle_response(
             resp,
             "Deployment by name fetched successfully",
@@ -347,13 +348,14 @@ class Deployment:
         if self.deployment_id is None:
             print("Deployment id not set for this model.")
             sys.exit(0)
-
         body = {"deploymentName": updated_name}
-
         headers = {"Content-Type": "application/json"}
         path = f"/v1/deployment/update_deployment_name/{self.deployment_id}"
-        resp = self.rpc.put(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.put(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             f"Deployment name updated to {updated_name}",
@@ -388,7 +390,6 @@ class Deployment:
         >>>     pprint(delete)
         """
         path = f"/v1/deployment/delete_deployment/{self.deployment_id}"
-
         resp = self.rpc.delete(path=path)
         return handle_response(
             resp,
@@ -396,7 +397,6 @@ class Deployment:
             "An error occurred while trying to delete the deployment.",
         )
 
-
     def get_deployment_server(self, model_train_id, model_type):
         """
         Fetch information about the deployment server for a specific model.
@@ -434,7 +434,7 @@ class Deployment:
 
     def wakeup_deployment_server(self):
         """
-        Wake up the deployment server associated with the current deployment. 
+        Wake up the deployment server associated with the current deployment.
         The `deployment_id` must be set during initialization.
 
         Returns
@@ -468,7 +468,7 @@ class Deployment:
 
     def _get_deployment_status_cards(self):
         """
-        Fetch status cards for the deployments within the current project. 
+        Fetch status cards for the deployments within the current project.
         The `project_id` must be set during initialization.
 
         Returns
@@ -509,7 +509,8 @@ class Deployment:
         -------
         tuple
             A tuple containing three elements:
-            - dict: The API response with details of the created authentication key, including keys such as:
+            - dict: The API response with details of the created authentication key,
+            including keys such as:
                 - `authKey` (str): The newly created authentication key.
                 - `expiryDate` (str): Expiration date of the key.
             - str or None: Error message if an error occurred, otherwise None.
@@ -523,22 +524,26 @@ class Deployment:
         >>> else:
         >>>     pprint(auth_key)
         """
-        body = {"expiryDays": expiry_days, "authType": "external"}
-
+        body = {
+            "expiryDays": expiry_days,
+            "authType": "external",
+        }
         headers = {"Content-Type": "application/json"}
         path = f"/v1/deployment/add_auth_key/{self.deployment_id}?projectId={self.project_id}"
-
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Auth Key created successfully.",
             "An error occurred while trying to create auth key.",
         )
 
-    
     def delete_auth_key(self, auth_key):
         """
-        Delete a specified authentication key for the current deployment. 
+        Delete a specified authentication key for the current deployment.
         The `deployment_id` must be set during initialization.
 
         Parameters
@@ -570,21 +575,19 @@ class Deployment:
         if self.deployment_id is None:
             print("Deployment id not set for this deployment.")
             sys.exit(0)
-
         path = f"/v1/deployment/delete_auth_key/{self.deployment_id}/{auth_key}"
-
         resp = self.rpc.delete(path=path)
         return handle_response(
             resp,
             "Auth key deleted successfully.",
             "An error occurred while trying to delete the auth key.",
         )
-        
+
     def request_total_monitor(self):
         """
         Monitor the total number of requests for the current deployment.
 
-        This method checks the total request count for a deployment by its `deployment_id`. 
+        This method checks the total request count for a deployment by its `deployment_id`.
         If `deployment_id` is not set, it attempts to fetch it using `deployment_name`.
 
         Returns
@@ -609,33 +612,46 @@ class Deployment:
         >>> else:
         >>>     pprint(monitor)
         """
-        # Check if deployment_id exists
         if self.deployment_id:
             deployment_id_url = self.deployment_id
-        # If not, check if deployment_name exists and fetch deployment_id
         elif self.deployment_name:
             _, error, _ = self._get_deployment_by_name()
             if error:
-                return None, error, "Failed to fetch deployment ID using the deployment name."
-            deployment_id_url = self.deployment_id  # Assuming _get_deployment_by_name sets self.deployment_id
+                return (
+                    None,
+                    error,
+                    "Failed to fetch deployment ID using the deployment name.",
+                )
+            deployment_id_url = self.deployment_id
         else:
-            return None, "Deployment ID and name are not set.", "Cannot perform operation without a deployment ID or name."
-
+            return (
+                None,
+                "Deployment ID and name are not set.",
+                "Cannot perform operation without a deployment ID or name.",
+            )
         path = f"/v1/model_prediction/monitor/req_total/{deployment_id_url}?projectId={self.project_id}"
         headers = {"Content-Type": "application/json"}
         body = {}
-
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Request total monitored successfully",
             "An error occurred while monitoring the request total.",
         )
 
-
-    def request_count_monitor(self, start_date, end_date, granularity="second"):
+    def request_count_monitor(
+        self,
+        start_date,
+        end_date,
+        granularity="second",
+    ):
         """
-        Monitor the count of requests within a specified time range and granularity for the current deployment.
+        Monitor the count of requests within a specified time range and granularity for the current
+            deployment.
 
         Parameters
         ----------
@@ -644,7 +660,8 @@ class Deployment:
         end_date : str
             The end date of the monitoring period in ISO format.
         granularity : str, optional
-            The time granularity for the request count (e.g., "second", "minute"). Default is "second".
+            The time granularity for the request count (e.g., "second", "minute")
+            . Default is "second".
 
         Returns
         -------
@@ -667,7 +684,7 @@ class Deployment:
         >>> else:
         >>>     pprint(count_monitor)
         """
-        path = f"/v1/model_prediction/monitor/request_count"
+        path = "/v1/model_prediction/monitor/request_count"
         headers = {"Content-Type": "application/json"}
         body = {
             "granularity": granularity,
@@ -676,17 +693,26 @@ class Deployment:
             "status": "REQ. COUNT",
             "deploymentId": self.deployment_id,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Request count monitored successfully",
             "An error occurred while monitoring the request count.",
         )
 
-    def request_latency_monitor(self, start_date, end_date, granularity="second"):
+    def request_latency_monitor(
+        self,
+        start_date,
+        end_date,
+        granularity="second",
+    ):
         """
-        Monitor the request latency within a specified time range and granularity for the current deployment.
+        Monitor the request latency within a specified time range and granularity for the current
+            deployment.
 
         Parameters
         ----------
@@ -695,7 +721,8 @@ class Deployment:
         end_date : str
             The end date of the monitoring period in ISO format.
         granularity : str, optional
-            The time granularity for latency tracking (e.g., "second", "minute"). Default is "second".
+            The time granularity for latency tracking (e.g., "second", "minute"). Default is
+                "second".
 
         Returns
         -------
@@ -704,7 +731,8 @@ class Deployment:
             - dict: The API response with latency details, structured as:
                 - `latencies` (list of dict): Each entry contains:
                     - `timestamp` (str): The timestamp of the latency record.
-                    - `avg_latency` (float): The average latency in seconds for the requests at that timestamp.
+                    - `avg_latency` (float): The average latency in seconds for the requests at
+                        that timestamp.
             - str or None: Error message if an error occurred, otherwise None.
             - str: Status message indicating success or failure of the API call.
 
@@ -719,7 +747,7 @@ class Deployment:
         >>> else:
         >>>     pprint(result)
         """
-        path = f"/v1/model_prediction/monitor/latency"
+        path = "/v1/model_prediction/monitor/latency"
         headers = {"Content-Type": "application/json"}
         body = {
             "granularity": granularity,
@@ -728,14 +756,17 @@ class Deployment:
             "status": "AVG. LATENCY",
             "deploymentId": self.deployment_id,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         return handle_response(
             resp,
             "Latency count monitored successfully",
             "An error occurred while monitoring the latency count.",
         )
-    
+
     def create_dataset(
         self,
         dataset_name,
@@ -794,15 +825,15 @@ class Deployment:
         >>> else:
         ...     pprint(resp)
         """
-        dataset_size, err, msg = self._get_dataset_size(source_url) #TODO: Implement get_dataset_size
+        dataset_size, err, msg = self._get_dataset_size(source_url)
         print(f"dataset size is = {dataset_size}")
         path = f"/v1/dataset/deployment?projectId={self.project_id}"
         headers = {"Content-Type": "application/json"}
         body = {
             "name": dataset_name,
-            "isUnlabeled": is_unlabeled,  # false,
-            "source": source,  # "lu",
-            "sourceUrl": source_url,  # "https://s3.us-west-2.amazonaws.com/dev.dataset/test%2Fb34ea15a-1f52-48a3-9a70-d43688084441.zip",
+            "isUnlabeled": is_unlabeled,
+            "source": source,
+            "sourceUrl": source_url,
             "_idDeployment": self.deployment_id,
             "cloudProvider": "AWS",
             "isCreateNew": True,
@@ -810,7 +841,7 @@ class Deployment:
             "newDatasetVersion": "v1.0",
             "datasetDescription": dataset_description,
             "newVersionDescription": version_description,
-            "isPublic": is_public,  # false,
+            "isPublic": is_public,
             "computeAlias": "",
             "targetCloudStorage": "GCP",
             "inputType": self.model_input,
@@ -823,27 +854,38 @@ class Deployment:
             "_idProject": self.project_id,
             "type": self.model_type,
         }
-        resp = self.rpc.post(path=path, headers=headers, payload=body)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=body,
+        )
         print(resp)
-
         return handle_response(
             resp,
             "Dataset creation in progress",
             "An error occured while trying to create new dataset",
-        )       
+        )
 
-    def get_prediction(self, image_path , auth_key):
+    def set_auth_key(self, auth_key):
+        self.auth_key = auth_key
+
+    def get_prediction(
+        self,
+        input_path=None,
+        auth_key="",
+        input_url=None,
+        extra_params={},
+    ):
         """
         Fetch model predictions for a given image using a deployment.
 
-        This method sends an image to the deployment for prediction. Either `deployment_id` 
+        This method sends an image to the deployment for prediction. Either `deployment_id`
         or `deployment_name` must be provided in the instance to locate the deployment.
 
         Parameters
         ----------
-        image_path : str
-            The path to the image for prediction.
+        input_path : str
+            The path to the input for prediction.
         auth_key : str
             The authentication key required for authorizing the prediction request.
 
@@ -861,13 +903,14 @@ class Deployment:
         Raises
         ------
         ValueError
-            If `auth_key` is not provided or if neither `deployment_id` nor `deployment_name` is set.
+            If `auth_key` is not provided or if neither `deployment_id` nor `deployment_name` is
+                set.
 
         Examples
         --------
         >>> from pprint import pprint
         >>> result, error, message = deployment.get_prediction(
-        ...     image_path="/path/to/image.jpg", 
+        ...     input_path="/path/to/input.jpg",
         ...     auth_key="auth123"
         ... )
         >>> if error:
@@ -876,43 +919,57 @@ class Deployment:
         ...     pprint(result)
         """
         if not auth_key:
-            raise ValueError("auth_key is required for deployment predictions.")
-
-        files = {"image": open(image_path, "rb")}
-
+            auth_key = self.auth_key
+            if not auth_key:
+                raise ValueError("auth_key is required for deployment predictions.")
+        if not any([input_path, input_url]):
+            raise ValueError("Either input_path or input_url must be provided.")
+        files = {}
+        data = {"authKey": auth_key}
+        if input_path:
+            files = {"input": open(input_path, "rb")}
+        if input_url:
+            data["inputUrl"] = input_url
+        if extra_params:
+            data["extraParams"] = json.dumps(extra_params)
         if self.deployment_id:
             url = f"/v1/model_prediction/deployment/{self.deployment_id}/predict"
         elif self.deployment_name:
             url = f"/v1/model_prediction/deployment_name/{self.deployment_name}/predict"
         else:
             raise ValueError("Either deployment_id or deployment_name must be provided.")
-
-        # Check if the server is running
         server_status, error, message = self._get_details()
         if error:
             print(f"Error checking server status: {error}")
             return None, error, message
-
         if server_status["status"] != "active":
-            # Wake up the server if it's not running
-            wakeup_resp, wakeup_error, wakeup_message = self.wakeup_deployment_server()
+            (
+                wakeup_resp,
+                wakeup_error,
+                wakeup_message,
+            ) = self.wakeup_deployment_server()
             if wakeup_error:
                 print(f"Error waking up server: {wakeup_error}")
-                return None, wakeup_error, wakeup_message
-
-            # Wait for the server to be fully awake
-            import time
-            time.sleep(10)  # Adjust the sleep time as needed
-
-
-        data = {"authKey": auth_key}
+                return (
+                    None,
+                    wakeup_error,
+                    wakeup_message,
+                )
+            time.sleep(10)
         headers = {"Authorization": f"Bearer {self.rpc.AUTH_TOKEN.bearer_token}"}
-
-        resp = self.rpc.post(url, headers=headers, data=data, files=files)
+        resp = self.rpc.post(
+            url,
+            headers=headers,
+            data=data,
+            files=files,
+        )
         success_message = "Model prediction fetched successfully"
         error_message = "An error occurred while fetching the model prediction."
-
-        return handle_response(resp, success_message, error_message)
+        result, error, message = handle_response(resp, success_message, error_message)
+        if error:
+            print(f"Error fetching model prediction: {error}")
+            return None, error, message
+        return result
 
     def _get_dataset_size(self, url):
         """
@@ -941,13 +998,16 @@ class Deployment:
         >>> else:
         ...     print(f"Dataset size: {size['size_in_mb']} MB")
         """
-        path = (
-            f"/v1/dataset/get_dataset_size_in_mb_from_url?projectId={self.project_id}"
-        )
+        path = f"/v1/dataset/get_dataset_size_in_mb_from_url?projectId={self.project_id}"
         requested_payload = {"datasetUrl": url}
         headers = {"Content-Type": "application/json"}
-        resp = self.rpc.post(path=path, headers=headers, payload=requested_payload)
-
+        resp = self.rpc.post(
+            path=path,
+            headers=headers,
+            payload=requested_payload,
+        )
         return handle_response(
-            resp, f"Dataset size fetched successfully", "Could not fetch dataset size"
+            resp,
+            "Dataset size fetched successfully",
+            "Could not fetch dataset size",
         )
